@@ -74,6 +74,9 @@ handler_predict.default <- function(vetiver_model, ...)
 #' @return A converted dataframe
 #' @export
 vetiver_type_convert <- function(new_data, ptype) {
+    if (is.null(ptype)) {
+        return(new_data)
+    }
     new_data <- hardhat::validate_column_names(new_data, colnames(ptype))
     spec <- readr::as.col_spec(ptype)
     is_character <- vapply(new_data, is.character, logical(1))
